@@ -7,9 +7,13 @@ Todo:
 """
 
 import pkg_resources
-from .fetch import browse, WaybackMachineRecord, WaybackMachineError
+from .browse import browse
+from .fetch import fetch
+from ._common import WaybackMachineRecord, WaybackMachineError
 
 try:
     __version__ = pkg_resources.get_distribution("waybackmachine").version
 except:
-    __version__ = None
\ No newline at end of file
+    __version__ = None
+
+__all__ = ["browse", "fetch", "WaybackMachineRecord", "WaybackMachineError"]
\ No newline at end of file
